API reference
#############

*DISCLAIMER: The API is not stable yet and subject to change.*

This document is the API reference for Ytpb.

**Top-level API**

.. toctree::
    :maxdepth: 2

    ytpb

**Module-level APIs**

.. toctree::
    :maxdepth: 2

    ytpb.actions

.. toctree::
    :maxdepth: 1

    ytpb.cache
    ytpb.download
    ytpb.errors
    ytpb.fetchers
    ytpb.info
    ytpb.locate
    ytpb.merge
    ytpb.playback
    ytpb.representations
    ytpb.segment
    ytpb.streams
